import { __decorate } from "tslib";
import { TypeRampValues } from '@genesislcap/foundation-utils';
import { bodyFont, typeRampBaseFontSize, typeRampBaseLineHeight, typeRampMinus1FontSize, typeRampMinus1LineHeight, typeRampMinus2FontSize, typeRampMinus2LineHeight, typeRampPlus1FontSize, typeRampPlus1LineHeight, typeRampPlus2FontSize, typeRampPlus2LineHeight, typeRampPlus3FontSize, typeRampPlus3LineHeight, typeRampPlus4FontSize, typeRampPlus4LineHeight, typeRampPlus5FontSize, typeRampPlus5LineHeight, typeRampPlus6FontSize, typeRampPlus6LineHeight, } from '@microsoft/fast-components';
import { customElement, FASTElement, observable } from '@microsoft/fast-element';
import { EventName } from '../design-system-editor';
import { TypographyStyles as styles } from './typography-tokens.styles';
import { TypographyTemplate as template } from './typography-tokens.template';
let TypographyTokens = class TypographyTokens extends FASTElement {
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            const detail = e.detail;
            this.applyStyleChanges(detail);
        });
    }
    applyStyleChanges(detail) {
        bodyFont.setValueFor(this.provider, detail.bodyFont);
        typeRampBaseFontSize.setValueFor(this.provider, detail.baseFontSize);
        typeRampBaseLineHeight.setValueFor(this.provider, detail.baseLineHeight);
        typeRampMinus1FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.minusOne));
        typeRampMinus1LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.minusOne));
        typeRampMinus2FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.minusTwo));
        typeRampMinus2LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.minusTwo));
        typeRampPlus1FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusOne));
        typeRampPlus1LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusOne));
        typeRampPlus2FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusTwo));
        typeRampPlus2LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusTwo));
        typeRampPlus3FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusThree));
        typeRampPlus3LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusThree));
        typeRampPlus4FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusFour));
        typeRampPlus4LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusFour));
        typeRampPlus5FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusFive));
        typeRampPlus5LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusFive));
        typeRampPlus6FontSize.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseFontSize, TypeRampValues.plusSix));
        typeRampPlus6LineHeight.setValueFor(this.provider, this.getTypeRampSize(typeRampBaseLineHeight, TypeRampValues.plusSix));
    }
    getTypeRampSize(baseTypeRamp, value) {
        const regex = /^(\d+)([a-z]+)/i;
        const matches = baseTypeRamp.getValueFor(this.provider).match(regex);
        const baseFontValue = matches[1];
        const baseUnit = matches[2];
        const typeRampSize = Number(baseFontValue) + value;
        return typeRampSize + baseUnit;
    }
};
__decorate([
    observable
], TypographyTokens.prototype, "provider", void 0);
TypographyTokens = __decorate([
    customElement({
        name: 'typography-tokens',
        template,
        styles,
    })
], TypographyTokens);
export { TypographyTokens };
